@@ -1,9 +1,5 @@
 """Test blag."""
 
-
-# remove when we don't support py38 anymore
-from __future__ import annotations
-
 import os
 from argparse import Namespace
 from datetime import datetime
