@@ -1,9 +1,5 @@
 """Test markdown module."""
 
-
-# remove when we don't support py38 anymore
-from __future__ import annotations
-
 from datetime import datetime
 from typing import Any
 
